// Copyright (c) 2004 David Muse
// See the COPYING file for more information.

#include <rudiments/private/inttypes.h>
#include <rudiments/private/rudimentsinlines.h>

#include <termios.h>

// FIXME: can this be moved into serialportprofile.C
#include <unistd.h>
